@@ -40,44 +40,43 @@ sub get_params {
     return $_[0]->{'params'};
 }
 
+1;
+
+__DATA__
+
 =encoding utf8
 
 =head1 NAME
 
-Aliyun::Method::FcSmsNumSend- 阿里云SDK方法
+Aliyun::Method::FcSmsNumSend- 阿里大于发送短信
 
-=head1 SYNOPSIS
-
-
-=head1 DESCRIPTION
-
-L<Aliyun::Method::FcSmsNumSend> 阿里大于发送短信
-
-=head1 ATTRIBUTES
 
 =head1 METHODS
 
 =head2 set_rec_num
-set_rec_num('phone_no')
-设置接收号码
+
+  set_rec_num('phone_no')
+  设置接收号码
 
 =head2 set_sms_free_sign_name
-set_sms_free_sign_name()
-设置短信签名
+
+  set_sms_free_sign_name()
+  设置短信签名
 
 =head2 set_sms_template_code
-set_sms_template_code()
-设置短信模板id
+ 
+  set_sms_template_code()
+  设置短信模板id
 
 =head2 set_sms_param
-set_sms_param()
-设置短信内容替换
+
+  set_sms_param()
+  设置短信内容替换
 
 =head2 get_params
-%hash = get_params()
-获取提交的参数。该方法必须实现
+
+  %hash = get_params()
+  获取提交的参数。该方法必须实现
 
 =cut
 
-1;
-
